<?php

/**
 * @file
 * Content for Node Subpages: Field values
 */

// Plugin details
$plugin = array(
  'title' => t('Field'),
  'description' => t("Use a Field's value as the content for the subpage"),
  'dependencies' => array('field'),
  'config form' => 'node_subpages_content_field_config',
  'config save prep' => 'node_subpages_content_field_config_save_prep',
  'config summary' => 'node_subpages_content_field_config_summary',
  'content' => 'node_subpages_content_field_content',
);

/**
 * Config form for the 
 */
function node_subpages_content_field_config($type, $plugin_config) {
  $fields = field_info_instances('node', $type->type);
  $options = array('' => '-- Select One --');
  if ($fields) {
    foreach ($fields as $field_key => $field_details) {
      // Only allow Text fields to be used for subpages
      if ($field_details['widget']['module'] == 'text') {
        $options[$field_key] = $field_details['label'] . ' (' . $field_key . ')';
      }
    }
  }
  
  
  $form['field'] = array(
    '#type' => 'select',
    '#title' => t('Field'),
    '#description' => t('Text field to use as the content of this subpage.'),
    '#multiple' => FALSE,
    '#options' => $options,
    '#default_value' => isset($plugin_config['field']) ? $plugin_config['field'] : '',
  );
  return $form;
}


/**
 * Prep the config for save to the DB, by placing into an array
 */
function node_subpages_content_field_config_save_prep($values) {
  return array('field' => $values['field']);
}


/**
 * Return the content for a subpage for the given node and plugin config
 * Should this use field_attach_view? See node_build_content().
 */
function node_subpages_content_field_content($node, $plugin_config) {
  // Get the field content. This will be an array of items
  $items = field_get_items('node', $node, $plugin_config['field']);

  // Loop over the field values and run them through check_markup to make sure
  // that the text formats are used.
  $values = array();
  foreach ($items as $item) {
    $cleaned = trim(check_markup($item['value'], $item['format'], $node->language));
    if (!empty($cleaned)) {
      $values[]= $cleaned;
    }
  }

  // Finally, implode the fields
  return implode($values);
}


/**
 * Return a summary for the configuration
 *
 * @param $plugin_config
 * Array of config options for the plugin
 *
 * @param $details
 * Array of full details, including subpath, plugin, etc
 */
function node_subpages_content_field_config_summary($plugin_config, $details) {
  // Get all fields for this node type
  $fields = field_info_instances('node', $details['node_type']);
  // Get the chosen field
  $field = $fields[$plugin_config['field']];
  // Build a summary
  return t('Field: %field_name', array('%field_name' =>  $field['label']));
}
